durationtools.yield_all_positive_rationals_in_cantor_diagonalized_order
=======================================================================

.. autofunction:: abjad.tools.durationtools.yield_all_positive_rationals_in_cantor_diagonalized_order.yield_all_positive_rationals_in_cantor_diagonalized_order
